@@ -203,17 +203,9 @@ class DataFrameGroupBy(object):
                 )
                 and DataFrame(query_compiler=self._by.isna()).any(axis=None)
             ):
-                mask_nan_rows = self._df[self._by.columns].isna()
-                if (isinstance(mask_nan_rows, DataFrame)) and len(
-                    mask_nan_rows.columns
-                ) == 1:
-                    mask_nan_rows = mask_nan_rows.squeeze(axis=1)
-                idx_nan_rows = mask_nan_rows[
-                    mask_nan_rows.any(axis=1)
-                    if (isinstance(mask_nan_rows, DataFrame))
-                    else mask_nan_rows
-                ].index
-                result.loc[idx_nan_rows] = np.nan
+                mask_nan_rows = self._df[self._by.columns].isna().any(axis=1)
+                # drop NaN groups
+                result = result.loc[~mask_nan_rows]
             return result
 
         if freq is None and axis == 1 and self._axis == 0:
@@ -271,11 +263,7 @@ class DataFrameGroupBy(object):
     def apply(self, func, *args, **kwargs):
         if not isinstance(func, BuiltinFunctionType):
             func = wrap_udf_function(func)
-        return self._apply_agg_function(
-            # Grouping column in never dropped in groupby.apply, so drop=False
-            lambda df: df.apply(func, *args, **kwargs),
-            drop=False,
-        )
+        return self._apply_agg_function(lambda df: df.apply(func, *args, **kwargs))
 
     @property
     def dtypes(self):
@@ -284,7 +272,7 @@ class DataFrameGroupBy(object):
         if not self._as_index:
             return self.apply(lambda df: df.dtypes)
         else:
-            return self._apply_agg_function(lambda df: df.dtypes, drop=self._as_index)
+            return self._apply_agg_function(lambda df: df.dtypes)
 
     def first(self, **kwargs):
         return self._default_to_pandas(lambda df: df.first(**kwargs))
@@ -634,7 +622,18 @@ class DataFrameGroupBy(object):
         return self._default_to_pandas(lambda df: df.corr(**kwargs))
 
     def fillna(self, **kwargs):
-        result = self._apply_agg_function(lambda df: df.fillna(**kwargs))
+        new_groupby_kwargs = self._kwargs.copy()
+        new_groupby_kwargs["as_index"] = True
+        work_object = type(self)(
+            df=self._df,
+            by=self._by,
+            axis=self._axis,
+            idx_name=self._idx_name,
+            drop=self._drop,
+            squeeze=self._squeeze,
+            **new_groupby_kwargs,
+        )
+        result = work_object._apply_agg_function(lambda df: df.fillna(**kwargs))
         # pandas does not name the index on fillna
         result._query_compiler.set_index_name(None)
         return result
@@ -904,7 +903,7 @@ class DataFrameGroupBy(object):
             return result.squeeze()
         return result
 
-    def _apply_agg_function(self, f, drop=True, *args, **kwargs):
+    def _apply_agg_function(self, f, *args, **kwargs):
         """
         Perform aggregation and combine stages based on a given function.
 
@@ -912,7 +911,7 @@ class DataFrameGroupBy(object):
 
         Parameters
         ----------
-        f:
+        f: callable
             The function to apply to each group.
 
         Returns
